<?php

    declare(strict_types=1);
    
    /**
     * @author: Daniel Schmitzer (daschmi@daschmi.de)
     * @date: 09.06.22
     * @time: 10:17
     */
     
    namespace wpsg;
	
	class wpsg_invoice extends \wpsg_model {
		
		 static $_tableName = 'WPSG_TBL_RECHNUNGEN';
		
		 /**
		 * Lädt die Daten  
		 */
		public function load($invoice_id) {
		
			parent::load($invoice_id);
				
			$this->data = $this->db->fetchRow("SELECT I.* FROM `".WPSG_TBL_RECHNUNGEN."` AS I WHERE I.`id` = '".wpsg_q($invoice_id)."' ");
			
			if ($this->data === null || $this->data['id'] != $invoice_id) throw new \wpsg\Exception(
				wpsg_translate(__('Die Daten einer Rechnung konnten nicht geladen werden', 'wpsg'), $invoice_id)
			);
			
		}
		 
		public function isInvoice() {
			
			return $this->__get('rnr') !== '';
			
		}
		
		public function isStorno() {
			
			return $this->__get('gnr') !== '';
			
		}

		/**
		 * @return \wpsg_order 
		 */
		public function getOrder() {

			return \wpsg_order::getInstance(intval($this->__get('o_id')));
			
		}

		public function getDate($format = null) {
			
			if ($format === null) return $this->__get('datum');
			else if ($format === true) return $this->getDate('d.m.Y H:i:s');
			else return date($format, strtotime($this->__get('datum')));
			
		}
		
		/**
		 * @param bool $bLink
		 * @param \wpsg_order_product $oOrderProduct
		 *
		 * @return string
		 */
		public function getNr($bLink = false, $oOrderProduct = null) {
			
			$strReturn = '';
			
			if ($bLink) {
				
				$strTitle = wpsg_translate(__('Erstellt am #1#', 'wpsg'), wpsg_formatTimestamp(strtotime($this->__get('datum'))));
				
				$strReturn .= '<a title="'.$strTitle.'" class="link_invoice '.(($this->isStorno())?'bg_storno':'').' '.(($this->isInvoice())?'bg_invoice':'').'" href="';
				$strReturn .= wp_nonce_url(WPSG_URL_WP.'wp-admin/admin.php?page=wpsg-Order&action=ajax&noheader=1&mod=wpsg_mod_rechnungen&do=getRechnung&edit_id='.$this->getOrder()->getId().'&r_id='.$this->getId(), 'wpsg-mod_invoice-order_ajax-getRechnung-'.$this->getId());
				$strReturn .= '" target="_blank">';
				
			}
			
			if ($this->isInvoice()) $strReturn .= 'R '.$this->__get('rnr');
			else if ($this->isStorno()) $strReturn .= 'RK '.$this->__get('gnr');
			
			if ($oOrderProduct !== null) {
				
				$invoice_data = json_decode($oOrderProduct->getMeta('wpsg_mod_rechnungen_data', false, 'null'), true);
				if ($invoice_data !== null) {
					
					foreach ($invoice_data as $id) {
						
						if ($id['invoice_id'] === $this->getId()) {
							
							$strReturn .= ' <span title="'.wpsg_translate(__('#1# Stück enthalten', 'wpsg'), $id['amount']).'">('.$id['amount'].')</span>';
							
						}
						
					}
					
				}
				
			}
			
			if ($bLink) {
				
				$strReturn .= '</a>';
				
			}
			
			return $strReturn;
			
		}
		
	}